OrcCon 2002 Tournament 2 Los Angeles, California February 16th 2002 Stuart Smith Crypt (12 cards, min=6, max=15, avg=2.58) ----------------------------------------- 2x Mariana Gilbert 4 PRE cel Toreador:1 2x Gideon Fontaine 3 PRE Ventrue:1 2x Delilah Easton 2 pre Toreador:1 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Itzahk Levine 3 cel pre Ventrue:2 1x Frederick the Weak 2 pre Brujah antitribu:2 1x Vasilis, The Traitor of Don Cruez 2 pre Brujah:2 1x Angela Decker 1 pre Pander:2 1x Antoinette DuChamp 1 cel pre Caitiff:2 Library (66 cards) Master (24) 5x Anarch Revolt 1x Barrens, The 1x Curse of Nitocris 1x Dreams of the Sphinx 2x Effective Management 1x Fragment of the Book of Nod 2x Gird Minions 1x Hostile Takeover 2x Parthenon, The 1x Pentex(TM) Subversion 1x Presence 6x Sudden Reversal Action (17) 1x Entrancement 2x Intimidation 9x Legal Manipulations 5x Mind Numb Equipment (2) 2x Signet of King Saul, The Retainer (2) 2x Marijava Ghoul Action Modifier (8) 8x Aire of Elation Reaction (3) 3x Delaying Tactics Combat (10) 10x Majesty